<?php
/**
 * Set citation layout according to options
 *
 * @package Citation
 */

defined( 'WPINC' ) || exit;

/**
 * Layout manager.
 */
class Citation_Layout extends Citation_Base {

	/**
	 * The Construct
	 */
	public function __construct() {
		$this->add_action( 'citation_before_wrapper', 'add_header' );
		$this->add_action( 'citation_single_post_header_thumb', 'single_post_header_thumb' );
		$this->add_action( 'citation_before_footer', 'full_related_posts' );
		$this->add_action( 'citation_before_content', 'add_title_section' );
	}

	/**
	 * Add header
	 */
	public function add_header() {
		$hash   = array(
			'header-default' => 'default',
			'header-layout2' => 'layout2',
		);
		$layout = citation_get_settings( 'header_styles' );
		get_template_part( 'template-parts/header/header', isset( $hash[ $layout ] ) ? $hash[ $layout ] : $layout );
	}

	/**
	 * Single post header thumbnail
	 */
	public function single_post_header_thumb() {

		$header_animation = citation_get_post_header_effect();

		if ( has_post_thumbnail() ) {
			if ( ! $header_animation && citation_get_settings( 'show_single_featured' ) ) {
				echo '<div class="single-featured-image">';
				the_post_thumbnail( 'citation-single-featured', array( 'class' => 'single-post-image' ) );
				echo '</div>';
			}
		}
	}

	/**
	 * Single post related posts
	 */
	public function full_related_posts( $position = 'full' ) {

		if ( 'full' === citation_get_settings( 'related_posts_position' ) ) {
			citation_related_posts();
		}

	}

	/**
	 * Single post related posts
	 */
	public function add_title_section() {

		$header_animation = citation_get_post_header_effect();

		if ( citation_get_settings( 'show_single_featured' ) && $header_animation ) {
			citation_single_featured_image_effect();
		}
	}

}

// Init.
new Citation_Layout;
