<?php

/**
 * Site Logo
 *
 * @param array $args
 * @return void
 */
if ( ! function_exists( 'citation_logo' ) ) {
	function citation_logo( $args = array(), $loc = 'mts' ) {

		$citation_logo = wp_get_attachment_url( citation_get_settings( $loc . '_logo' ) );

		$h_tag     = 'h2';
		$logo_type = 'text-logo';

		if ( is_front_page() || is_home() || is_404() ) {
			$h_tag = 'h1';
		}

		if ( 'footer' === $loc ) {
			$h_tag = 'div';
		}

		if ( ! empty( $citation_logo ) ) {
			$logo_type = 'image-logo';
		}

		$defaults = array(
			'logo'   => $citation_logo,
			'url'    => esc_url( home_url() ),
			'title'  => get_bloginfo( 'name' ),
			'before' => '<' . $h_tag . ' id="logo" class="' . $logo_type . ' clearfix" itemprop="headline">',
			'after'  => '</' . $h_tag . '>',
		);

		$args = wp_parse_args( $args, $defaults );

		$output = $args['logo'] ? sprintf( '<img src="' . $args['logo'] . '" alt="' . esc_attr( $args['title'] ) . '">' ) : $args['title'];
		$output = sprintf( '<a href="%1$s">%2$s</a>', $args['url'], $output );

		echo wp_kses_post( $args['before'] ) . $output . wp_kses_post( $args['after'] );
	}
}

/**
 * Template functions that the framework or themes may use.
 */

/**
 * Single Post Header Layout type (Parallax or Zoomout) *
 */
function citation_single_featured_image_effect() {

	if ( is_home() ) {
		return;
	}

	$header_animation = citation_get_post_header_effect();

	if ( has_post_thumbnail() ) {
		if ( 'parallax' === $header_animation ) {
			echo '<div id="parallax" style="background-image: url(' . get_the_post_thumbnail_url( get_the_ID(), 'full' ) . ');"></div>';
		} elseif ( 'zoomout' === $header_animation ) {
			echo '<div id="zoom-out-effect"><div id="zoom-out-bg" style="background-image: url(' . get_the_post_thumbnail_url( get_the_ID(), 'full' ) . ');"></div></div>';
		}
	}

}

/**
 * Display citation-compliant the_tags()
 *
 * @param string $before
 * @param string $sep
 * @param string $after
 */
if ( ! function_exists( 'citation_post_tags' ) ) {
	function citation_post_tags( $before = '', $sep = ', ', $after = '</div>' ) {
		if ( empty( $before ) ) {
			$before = '<div class="tags">' . esc_html__( 'Tags: ', 'citation' );
		}
		$tags = get_the_tags();
		if ( empty( $tags ) || is_wp_error( $tags ) ) {
			return;
		}
		$tag_links = array();
		foreach ( $tags as $tag ) {
			$link        = get_tag_link( $tag->term_id );
			$tag_links[] = '<a href="' . esc_url( $link ) . '" rel="tag">' . $tag->name . '</a>';
		}
		echo $before . join( $sep, $tag_links ) . $after;
	}
}

/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function citation_categorized_blog() {
	$category_count = get_transient( 'citation_categories' );

	if ( false === $category_count ) {
		// Create an array of all the categories that are attached to posts.
		$categories = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,
			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$category_count = count( $categories );

		set_transient( 'citation_categories', $category_count );
	}

	return $category_count > 1;
}

/**
 * Display the post info block.
 *
 * @param string $section
 */
function citation_the_post_meta( $section = 'home', $groupid = '' ) {

	if ( 'archive' === $section ) {
		$enabled_metas = citation_get_settings( 'archive_post_meta_info' );
	} else {
		$enabled_metas = citation_get_settings( 'mts_' . $section . '_headline_meta_info' . $groupid );
	}

	$enabled_metas = isset( $enabled_metas['enabled'] ) ? $enabled_metas['enabled'] : array();

	if ( ! empty( $enabled_metas ) ) :
	?>
		<div class="post-info">
			<?php
			foreach ( $enabled_metas as $key => $title ) {
				if ( 'single' === $section ) :
					$pagename = 'mts_single';
					$suffix   = '';
				elseif ( 'archive' === $section ) :
					$pagename = 'archive';
					$suffix   = '';
				else :
					$pagename = 'mts';
					$suffix   = '_';
				endif;

				$author_icon = ( citation_get_settings( $pagename . '_meta_info_author_icon' . $suffix . $groupid ) ) ? '<i class="fa fa-' . citation_get_settings( $pagename . '_meta_info_author_icon' . $suffix . $groupid ) . '"></i>' : '';

				$date_icon = ( citation_get_settings( $pagename . '_meta_info_date_icon' . $suffix . $groupid ) ) ? '<i class="fa fa-' . citation_get_settings( $pagename . '_meta_info_date_icon' . $suffix . $groupid ) . '"></i>' : '';

				$category_icon = ( citation_get_settings( $pagename . '_meta_info_category_icon' . $suffix . $groupid ) ) ? '<i class="fa fa-' . citation_get_settings( $pagename . '_meta_info_category_icon' . $suffix . $groupid ) . '"></i>' : '';

				$comment_icon = ( citation_get_settings( $pagename . '_meta_info_comment_icon' . $suffix . $groupid ) ) ? '<i class="fa fa-' . citation_get_settings( $pagename . '_meta_info_comment_icon' . $suffix . $groupid ) . '"></i>' : '';

				switch ( $key ) {

					case 'author':
						printf( '<span class="theauthor">%1$s<span>%2$s</span></span>', $author_icon, get_the_author_posts_link() );
						break;

					case 'date':
						printf( '<span class="thetime date updated">%1$s<span>%2$s</span></span>', $date_icon, get_the_time( get_option( 'date_format' ) ) );
						break;

					case 'category':
						printf( '<span class="thecategory">%1$s%2$s</span>', $category_icon, citation_get_the_category( ', ' ) );
						break;

					case 'comment':
						printf( '<span class="thecomment">%1$s<a href="%2$s" itemprop="interactionCount">%3$s</a></span>', $comment_icon, esc_url( get_comments_link() ), get_comments_number_text() );
						break;
				}
			}
			?>
		</div>
	<?php
	endif;
}

/**
 * Display citation-compliant the_category()
 *
 * @param string $separator
 */
function citation_get_the_category( $separator = ', ' ) {
	$categories = get_the_category();

	if ( empty( $categories ) ) {
		return;
	}

	global $wp_rewrite;

	$links = array();
	$rel   = ( is_object( $wp_rewrite ) && $wp_rewrite->using_permalinks() ) ? 'rel="category tag"' : 'rel="category"';

	foreach ( $categories as $category ) {

		$links[] = sprintf(
			'<a href="%1$s" title="%2$s" %3$s>%4$s</a>',
			esc_url( get_category_link( $category->term_id ) ),
			// translators: category name.
			sprintf( esc_html__( 'View all posts in %s', 'citation' ), esc_attr( $category->name ) ),
			$rel,
			esc_html( $category->name )
		);
	}

	return join( $separator, $links );
}

/**
 * Display the pagination.
 *
 * @param string $nav_type
 */
function citation_pagination( $nav_type = '' ) {

	if ( 1 === $GLOBALS['wp_query']->max_num_pages ) {
		return;
	}

	if ( 1 === $nav_type ) { // Numeric pagination.
		the_posts_pagination( array(
			'mid_size'  => 3,
			'prev_text' => '<i class="fa fa-angle-left"></i>' . esc_html__( 'Previous', 'citation' ) . ' ',
			'next_text' => esc_html__( 'Next', 'citation' ) . '<i class="fa fa-angle-right"></i>',
		) );
	} else { // traditional or ajax pagination.
		?>
		<div class="pagination pagination-previous-next">
			<ul>
				<li class="nav-previous"><?php next_posts_link( esc_html__( 'Previous', 'citation' ) ); ?></li>
				<li class="nav-next"><?php previous_posts_link( esc_html__( 'Next', 'citation' ) ); ?></li>
			</ul>
		</div>
		<?php
	}
}

/**
 * Create and show column for featured image in the post list of admin page
 * @param $post_id
 * @return string url
 */
if ( ! function_exists( 'citation_get_featured_image' ) ) {
	function citation_get_featured_image( $post_id ) {
		if ( $post_thumbnail_id = get_post_thumbnail_id( $post_id ) ) { // @codingStandardsIgnoreLine
			$post_thumbnail_img = wp_get_attachment_image_src( $post_thumbnail_id, 'citation-widgetfull' );
			return $post_thumbnail_img[0];
		}
	}
}

/**
 * Adds a `Featured Image` column header in the Post list of admin page
 *
 * @param array $defaults
 * @return array
 */
if ( ! function_exists( 'citation_columns_head' ) ) {
	function citation_columns_head( $defaults ) {
		if ( 'post' === get_post_type() ) {
			$defaults['featured_image'] = __( 'Featured Image', 'citation' );
		}

		return $defaults;
	}
}
add_filter( 'manage_posts_columns', 'citation_columns_head' );

/**
 * Adds a `Featured Image` column row value in the Post list of admin page
 *
 * @param string $column_name The name of the column to display.
 * @param int $post_id The ID of the current post.
 */
if ( ! function_exists( 'citation_columns_content' ) ) {
	function citation_columns_content( $column_name, $post_id ) {
		if ( 'featured_image' === $column_name ) {
			if ( $post_featured_image = citation_get_featured_image( $post_id ) ) { // @codingStandardsIgnoreLine
				echo '<img width="150" height="100" src="' . esc_url( $post_featured_image ) . '" />';
			}
		}
	}
}
add_action( 'manage_posts_custom_column', 'citation_columns_content', 10, 2 );

/**
 * Footer Widget Columns
 *
 * @return string
 */
function citation_footer_widget_columns() {

	$footer_columns = intval( citation_get_settings( 'mts_top_footer_num' ) );

	if ( ! $footer_columns ) {
		return;
	}
	?>

		<div class="footer-widgets first-footer-widgets widgets-num-<?php echo esc_attr( $footer_columns ); ?>">
			<div class="container">
				<?php
				for ( $i = 1; $i <= $footer_columns; $i++ ) :
					$class = '';
					if ( $i === $footer_columns ) {
						$class = ' last';
					} elseif ( 1 === $i ) {
						$class = ' first';
					}
					?>
					<div class="f-widget f-widget-<?php echo esc_attr( $i ) . esc_attr( $class ); ?>">
						<?php dynamic_sidebar( 'footer-top-' . $i ); ?>
					</div>
				<?php endfor; ?>
			</div>
		</div><!--.first-footer-widgets-->
	<?php
}

/**
 * Locations section
 *
 * @return string
 */
function locations_layout() {
	$img              = citation_get_settings( 'locations_image' );
	$heading          = citation_get_settings( 'locations_heading' );
	$subheading       = citation_get_settings( 'locations_subheading' );
	$button_text      = citation_get_settings( 'locations_button_text' );
	$button_url       = citation_get_settings( 'locations_button_url' );
	$locations_styles = ! empty( citation_get_settings( 'locations_styles' ) ) ? citation_get_settings( 'locations_styles' ) : 'default';
	if ( empty( $img ) && empty( $heading ) && empty( $subheading ) && empty( $button_text ) && empty( $button_url ) ) {
		return;
	}
	echo '<section class="locations-section clearfix">';
	echo '<div class="container clearfix">';
	echo '<div class="locations-wrapper ' . $locations_styles . '">';
	switch ( $locations_styles ) {
		case 'default':
			if ( ! empty( $heading ) || ! empty( $subheading ) ) {
				echo '<header>';
			}
			if ( ! empty( $heading ) ) {
				echo '<h2>' . $heading . '</h2>';
			}
			if ( ! empty( $subheading ) ) {
				echo '<p>' . $subheading . '</p>';
			}
			if ( ! empty( $heading ) || ! empty( $subheading ) ) {
				echo '</header>';
			}
			if ( ! empty( $img ) ) {
				echo '<div class="locations-img"><img src="' . $img . '"></div>';
			}
			if ( ! empty( $button_text ) && ! empty( $button_url ) ) {
				printf( '<div class="locations-button"><a class="button" href="%1$s">%2$s</a></div>', $button_url, $button_text );
			}
			break;

		case 'locations2':
		case 'locations3':
			echo '<div class="locations-content">';
			if ( ! empty( $heading ) ) {
				echo '<h2>' . $heading . '</h2>';
			}
			if ( ! empty( $subheading ) ) {
				echo '<p>' . $subheading . '</p>';
			}
			if ( ! empty( $button_text ) && ! empty( $button_url ) ) {
				printf( '<div class="locations-button"><a class="button" href="%1$s">%2$s</a></div>', $button_url, $button_text );
			}
			echo '</div>';
			if ( ! empty( $img ) ) {
				echo '<div class="locations-img"><img src="' . $img . '"></div>';
			}
			break;

		default:
			if ( ! empty( $heading ) ) {
				echo '<h2>' . $heading . '</h2>';
			}
			if ( ! empty( $subheading ) ) {
				echo '<p>' . $subheading . '</p>';
			}
			if ( ! empty( $img ) ) {
				echo '<div class="locations-img"><img src="' . $img . '"></div>';
			}
			if ( ! empty( $button_text ) && ! empty( $button_url ) ) {
				printf( '<div class="locations-button"><a class="button" href="%1$s">%2$s</a></div>', $button_url, $button_text );
			}
			break;
	}
	echo '</div>';
	echo '</div>';
	echo '</section>';
}

/**
 * Copyrights section
 *
 * @return string
 */
function citation_footer_copyrights() {
	$content = citation_get_settings( 'mts_copyrights' );

	$copyright_text = '<a href=" ' . esc_url( trailingslashit( home_url() ) ) . '" title=" ' . get_bloginfo( 'description' ) . '">' . get_bloginfo( 'name' ) . '</a> ' . __( 'Copyright', 'citation' ) . ' &copy; ' . date( 'Y' ) . '.';
	?>
	<div class="copyrights">
		<div class="container">
			<div class="row" id="copyright-note">
				<div class="to-left"><?php echo $copyright_text; ?></div>
				<div class="to-top"><?php echo $content; ?></div>
			</div>
		</div>
	</div>
	<?php
}

/**
 * Citation display comments
 */
function citation_display_comments() {
	// If comments are open or we have at least one comment, load up the comment template.
	if ( comments_open() || 0 !== intval( get_comments_number() ) ) :
		comments_template();
	endif;
}

if ( ! function_exists( 'citation_comments' ) ) {
	/**
	 * Custom comments template.
	 *
	 * @param array $comment    get comment.
	 * @param array $args
	 * @param int   $depth    child depth.
	 */
	function citation_comments( $comment, $args, $depth ) {
	?>
		<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
			<?php
			switch ( $comment->comment_type ) :
				case 'pingback':
				case 'trackback':
				?>
					<div id="comment-<?php comment_ID(); ?>">
						<div class="comment-author vcard">
							Pingback: <?php comment_author_link(); ?>
							<?php if ( ! empty( citation_get_settings( 'mts_comment_date' ) ) ) { ?>
								<span class="ago"><?php comment_date( get_option( 'date_format' ) ); ?></span>
							<?php } ?>
							<span class="comment-meta">
								<?php edit_comment_link( __( '( Edit )', 'citation' ), '  ', '' ); ?>
							</span>
						</div>
						<?php if ( '0' === $comment->comment_approved ) : ?>
							<em><?php esc_html_e( 'Your comment is awaiting moderation.', 'citation' ); ?></em>
							<br />
						<?php endif; ?>
					</div>
				<?php
					break;

				default:
				?>
					<div id="comment-<?php comment_ID(); ?>" itemscope itemtype="http://schema.org/UserComments">
						<div class="comment-author vcard">
							<?php echo get_avatar( $comment->comment_author_email, 92 ); ?>
							<?php printf( '<span class="fn" itemprop="creator" itemscope itemtype="http://schema.org/Person"><span itemprop="name">%s</span></span>', get_comment_author_link() ); ?>
							<?php if ( ! empty( citation_get_settings( 'mts_comment_date' ) ) ) { ?>
								<span class="ago"><?php comment_date( get_option( 'date_format' ) ); ?></span>
							<?php } ?>
							<span class="comment-meta">
								<?php edit_comment_link( __( '( Edit )', 'citation' ), '  ', '' ); ?>
							</span>
							<div class="reply">
								<?php
								comment_reply_link( array_merge( $args, array(
									'depth'     => $depth,
									'max_depth' => $args['max_depth'],
								) ) );
								?>
							</div>
						</div>
						<?php if ( '0' === $comment->comment_approved ) : ?>
							<em><?php esc_html_e( 'Your comment is awaiting moderation.', 'citation' ); ?></em>
							<br />
						<?php endif; ?>
						<div class="commentmetadata">
							<div class="commenttext" itemprop="commentText">
								<?php comment_text(); ?>
							</div>
						</div>
					</div>
				<?php
					break;
			endswitch;
			?>
	<!-- WP adds </li> -->
	<?php
	}
}

/**
 * Display a "read more" link.
 */
function citation_readmore() {
	?>
	<div class="readMore">
		<a href="<?php the_permalink(); ?>" class="button border" title="<?php the_title_attribute(); ?>"><?php esc_html_e( 'Read More', 'citation' ); ?></a>
	</div>
	<?php
}

if ( ! function_exists( 'citation_the_postinfo_item' ) ) {
	/**
	 * Display information of an item.
	 *
	 * @param $item
	*/
	function citation_the_postinfo_item( $item ) {

		$hash = array(
			'author'   => '<span class="theauthor"><i class="fa fa-user"></i> <span>' . get_the_author_posts_link() . '</span></span>',
			'date'     => '<span class="thetime date updated"><i class="fa fa-calendar"></i> <span>' . get_the_time( get_option( 'date_format' ) ) . '</span></span>',
			'category' => '<span class="thecategory"><i class="fa fa-tags"></i> ' . citation_get_the_category( ', ' ) . '</span>',
			'comment'  => '<span class="thecomment"><i class="fa fa-comments"></i> <a href="' . esc_url( get_comments_link() ) . '" itemprop="interactionCount"><?php comments_number();?></a></span>',
		);

		return isset( $hash[ $item ] ) ? $hash[ $item ] : '';
	}
}

// Last item in the breadcrumbs
if ( ! function_exists( 'get_itemprop_3' ) ) {
	function get_itemprop_3( $title = '', $position = '2' ) {
		echo '<div itemprop="itemListElement" itemscope itemtype="https://schema.org/ListItem">';
		echo '<span itemprop="name">' . $title . '</span>';
		echo '<meta itemprop="position" content="' . $position . '" />';
		echo '</div>';
	}
}
if ( ! function_exists( 'citation_breadcrumbs' ) ) {
	/**
	 * Display the breadcrumbs.
	 */
	function citation_breadcrumbs() {
		if ( is_front_page() ) {
				return;
		}
		if ( function_exists( 'rank_math_the_breadcrumbs' ) && RankMath\Helper::get_settings( 'general.breadcrumbs' ) ) {
			rank_math_the_breadcrumbs();
			return;
		}
		$arrow = citation_get_settings( 'breadcrumb_icon' );
		echo '<div class="breadcrumb" itemscope itemtype="https://schema.org/BreadcrumbList">';
		echo '<div itemprop="itemListElement" itemscope
	      itemtype="https://schema.org/ListItem" class="root"><a href="';
		echo esc_url( home_url() );
		echo '" itemprop="item"><span itemprop="name">' . esc_html__( 'Home', 'citation' );
		echo '</span><meta itemprop="position" content="1" /></a></div><div class="separator"><i class="fa fa-' . $arrow . '"></i></div>';
		if ( is_single() ) {
			$categories = get_the_category();
			if ( $categories ) {
				$level         = 0;
				$hierarchy_arr = array();
				foreach ( $categories as $cat ) {
					$anc       = get_ancestors( $cat->term_id, 'category' );
					$count_anc = count( $anc );
					if ( 0 < $count_anc && $level < $count_anc ) {
						$level         = $count_anc;
						$hierarchy_arr = array_reverse( $anc );
						array_push( $hierarchy_arr, $cat->term_id );
					}
				}
				if ( empty( $hierarchy_arr ) ) {
					$category = $categories[0];
					echo '<div itemprop="itemListElement" itemscope
				      itemtype="https://schema.org/ListItem"><a href="' . esc_url( get_category_link( $category->term_id ) ) . '" itemprop="item"><span itemprop="name">' . esc_html( $category->name ) . '</span><meta itemprop="position" content="2" /></a></div><div class="separator"><i class="fa fa-' . $arrow . '"></i></div>';
				} else {
					foreach ( $hierarchy_arr as $cat_id ) {
						$category = get_term_by( 'id', $cat_id, 'category' );
						echo '<div itemprop="itemListElement" itemscope
					      itemtype="https://schema.org/ListItem"><a href="' . esc_url( get_category_link( $category->term_id ) ) . '" itemprop="item"><span itemprop="name">' . esc_html( $category->name ) . '</span><meta itemprop="position" content="2" /></a></div><div class="separator"><i class="fa fa-' . $arrow . '"></i></div>';
					}
				}
				get_itemprop_3( get_the_title(), '3' );
			} else {
				get_itemprop_3( get_the_title() );
			}
		} elseif ( is_page() ) {
			$parent_id = wp_get_post_parent_id( get_the_ID() );
			if ( $parent_id ) {
				$breadcrumbs = array();
				while ( $parent_id ) {
					$page          = get_page( $parent_id );
					$breadcrumbs[] = '<div itemprop="itemListElement" itemscope
				      itemtype="https://schema.org/ListItem"><a href="' . esc_url( get_permalink( $page->ID ) ) . '" itemprop="item"><span itemprop="name">' . esc_html( get_the_title( $page->ID ) ) . '</span><meta itemprop="position" content="2" /></a></div><div class="separator"><i class="fa fa-' . $arrow . '"></i></div>';
					$parent_id = $page->post_parent;
				}
				$breadcrumbs = array_reverse( $breadcrumbs );
				foreach ( $breadcrumbs as $crumb ) { echo $crumb; }
				get_itemprop_3( get_the_title(), 3 );
			} else {
				get_itemprop_3( get_the_title() );
			}
		} elseif ( is_category() ) {
			global $wp_query;
			$cat_obj       = $wp_query->get_queried_object();
			$this_cat_id   = $cat_obj->term_id;
			$hierarchy_arr = get_ancestors( $this_cat_id, 'category' );
			if ( $hierarchy_arr ) {
				$hierarchy_arr = array_reverse( $hierarchy_arr );
				foreach ( $hierarchy_arr as $cat_id ) {
					$category = get_term_by( 'id', $cat_id, 'category' );
					echo '<div itemprop="itemListElement" itemscope
				      itemtype="https://schema.org/ListItem"><a href="' . esc_url( get_category_link( $category->term_id ) ) . '" itemprop="item"><span itemprop="name">' . esc_html( $category->name ) . '</span><meta itemprop="position" content="2" /></a></div><div class="separator"><i class="fa fa-' . $arrow . '"></i></div>';
				}
			}
			get_itemprop_3( single_cat_title( '', false ) );
		} elseif ( is_author() ) {
			if ( get_query_var( 'author_name' ) ) :
				$curauth = get_user_by( 'slug', get_query_var( 'author_name' ) );
			else :
				$curauth = get_userdata( get_query_var( 'author' ) );
			endif;
			get_itemprop_3( esc_html( $curauth->nickname ) );
		} elseif ( is_search() ) {
			get_itemprop_3( get_search_query() );
		} elseif ( is_tag() ) {
			get_itemprop_3( single_tag_title( '', false ) );
		}
		echo '</div>';
	}
}

if ( ! empty( citation_get_settings( 'mts_feedburner' ) ) ) {
	/**
	 * Redirect feed to FeedBurner if a FeedBurner URL has been set.
	 */
	function citation_rss_feed_redirect() {
		global $feed;
		$new_feed = citation_get_settings( 'mts_feedburner' );
		if ( ! is_feed() ) {
				return;
		}
		if ( preg_match( '/feedburner/i', $_SERVER['HTTP_USER_AGENT'] ) ) {
				return;
		}
		if ( 'comments-rss2' != $feed ) {
				if ( function_exists( 'status_header' ) ) status_header( 302 );
				header( "Location:" . $new_feed );
				header( "HTTP/1.1 302 Temporary Redirect" );
				exit();
		}
	}
	add_action( 'template_redirect', 'citation_rss_feed_redirect' );
}

/**
 * Related Posts Thumbnail.
 *
 * @param  string $thumb post thumbnail image.
 */
function get_related_post_thumb( $thumb = 'citation-related' ) {
?>
	<a href="<?php echo esc_url( get_the_permalink() ); ?>" title="<?php the_title_attribute(); ?>" id="featured-thumbnail">
		<div class="featured-thumbnail">
			<?php the_post_thumbnail( $thumb, array( 'title' => '' ) ); ?>
		</div>
		<?php
		if ( function_exists( 'wp_review_show_total' ) ) {
			wp_review_show_total( true, 'latestPost-review-wrapper' );
		}
		?>
	</a>
<?php
}
/**
 * Related Posts Title.
 */
function get_related_post_title() {
	citation_the_post_meta( 'related' );
	?>
	<h2 class="title front-view-title"><a href="<?php echo esc_url( get_the_permalink() ); ?>" title="<?php the_title_attribute(); ?>"><?php the_title(); ?></a></h2>
	<?php
}

function get_related_post_content() {
	?>
	<div class="front-view-content">
		<?php
		if ( empty( citation_excerpt() ) ) {
			echo citation_truncate( get_the_content(), citation_get_settings( 'related_excerpt' ), 'words' );
		} else {
			echo citation_excerpt( citation_get_settings( 'related_excerpt' ) );
		}
		?>
	</div>
	<?php
}

if ( ! function_exists( 'citation_related_posts' ) ) {
	/**
	 * Display the related posts.
	 */
	function citation_related_posts() {
		$post_id  = get_the_ID();
		$taxonomy = citation_get_settings( 'mts_related_posts_taxonomy' );

		if ( ! empty( citation_get_settings( 'mts_single_post_layout' )['enabled']['related'] ) ) {
			$empty_taxonomy = false;
			if ( $taxonomy && 'tags' === $taxonomy ) {
				// related posts based on tags
				$tags = get_the_tags( $post_id );
				if ( empty( $tags ) ) {
					$empty_taxonomy = true;
				} else {
					$tag_ids = array();
					foreach ( $tags as $individual_tag ) {
						$tag_ids[] = $individual_tag->term_id;
					}
					$args = array(
						'tag__in'             => $tag_ids,
						'post__not_in'        => array( $post_id ),
						'posts_per_page'      => ( null !== citation_get_settings( 'mts_related_postsnum' ) ) ? citation_get_settings( 'mts_related_postsnum' ) : 3,
						'ignore_sticky_posts' => 1,
						'orderby'             => 'rand',
					);
				}
			} else {
				// related posts based on categories
				$categories = get_the_category( $post_id );
				if ( empty( $categories ) ) {
					$empty_taxonomy = true;
				} else {
					$category_ids = array();
					foreach ( $categories as $individual_category ) {
						$category_ids[] = $individual_category->term_id;
					}
					$args = array(
						'category__in'        => $category_ids,
						'post__not_in'        => array( $post_id ),
						'posts_per_page'      => citation_get_settings( 'mts_related_postsnum' ),
						'ignore_sticky_posts' => 1,
						'orderby'             => 'rand',
					);
				}
			}
			if ( ! $empty_taxonomy ) {
				$my_query = new WP_Query( $args );
				if ( $my_query->have_posts() ) {

					$title = citation_get_settings( 'related_post_title' ) ? '<div class="related-posts-title"><h4>' . citation_get_settings( 'related_post_title' ) . '</h4></div>' : '';

					$related_posts_layouts = ! empty( citation_get_settings( 'related_posts_layouts' ) ) ? citation_get_settings( 'related_posts_layouts' ) : 'default';

					$grid = ! empty( citation_get_settings( 'related_posts_grid' ) ) && 'default' === $related_posts_layouts ? 'flex-grid ' . citation_get_settings( 'related_posts_grid' ) : 'flex-grid default';

					$position = ! empty( citation_get_settings( 'related_posts_position' ) ) ? citation_get_settings( 'related_posts_position' ) : 'default';
					echo '<div class="related-posts ' . $related_posts_layouts . ' position-' . $position . ' ">';
					echo ( 'full' === $position ) ? '<div class="container">' : '';
					echo $title;
					echo '<div class="related-posts-container clear">';

					$posts_per_row = 3;

					$j = 0;
					while ( $my_query->have_posts() ) {
						$my_query->the_post();
						switch ( $related_posts_layouts ) {
							case 'default':
								?>
								<article class="latestPost excerpt <?php echo $grid; ?>">
									<?php get_related_post_thumb(); ?>
									<div class="wrapper">
										<header>
											<?php get_related_post_title(); ?>
										</header>
										<?php
										get_related_post_content();
										if ( citation_get_settings( 'related_readmore_button' ) ) :
											citation_readmore();
										endif;
										?>
									</div>
								</article><!--.post.excerpt-->
								<?php
								break;

							case 'related2':
								?>
								<article class="latestPost excerpt <?php echo $grid; ?>">
									<?php get_related_post_thumb(); ?>
									<div class="wrapper">
										<header>
											<?php get_related_post_title(); ?>
										</header>
										<?php
										get_related_post_content();
										if ( citation_get_settings( 'related_readmore_button' ) ) :
											citation_readmore();
										endif;
										?>
									</div>
								</article><!--.post.excerpt-->
								<?php
								break;

							case 'related3':
								?>
								<article class="latestPost excerpt <?php echo $grid; ?>">
									<div class="wrapper">
										<header>
											<?php get_related_post_title(); ?>
										</header>
									</div>
								</article><!--.post.excerpt-->
								<?php
								break;

							case 'related5':
								?>
								<article class="latestPost excerpt flex-grid grid2">
									<?php get_related_post_thumb(); ?>
									<div class="wrapper">
										<header>
											<?php get_related_post_title(); ?>
										</header>
										<?php get_related_post_content(); ?>
									</div>
								</article><!--.post.excerpt-->
								<?php
								if ( 1 === ++$j ) {
									$ad_code = citation_get_settings( 'related_posts_adcode' );
									if ( ! empty( trim( $ad_code ) ) ) {
										echo '<div class="related-posts-ad">';
											echo do_shortcode( $ad_code );
										echo '</div>';
									}
								}
								break;

							case 'related6':
								?>
								<article class="latestPost excerpt <?php echo $grid; ?>">
									<div class="wrapper">
										<header>
											<?php get_related_post_title(); ?>
										</header>
									</div>
								</article><!--.post.excerpt-->
								<?php
								break;

							default:
								?>
								<article class="latestPost excerpt <?php echo $grid; ?>">
									<?php get_related_post_thumb(); ?>
									<div class="wrapper">
										<header>
											<?php get_related_post_title(); ?>
										</header>
										<?php
										get_related_post_content();
										if ( citation_get_settings( 'related_readmore_button' ) ) :
											citation_readmore();
										endif;
										?>
									</div>
								</article><!--.post.excerpt-->
								<?php
								break;
						}
					}
					echo '</div>';

					if ( 'related6' === citation_get_settings( 'related_posts_layouts' ) ) {
						$ad_code = citation_get_settings( 'related_posts_adcode' );
						if ( ! empty( trim( $ad_code ) ) ) {
							echo '<div class="related-posts-ad">';
								echo do_shortcode( $ad_code );
							echo '</div>';
						}
					}

					echo ( 'full' === $position ) ? '</div>' : '';
					echo '</div>';
				}
			}
			wp_reset_postdata();
			?>
		<!-- .related-posts -->
		<?php
		}
	}
}

/**
 * Display the Social Sharing buttons.
 */
if ( ! function_exists( 'citation_social_buttons' ) ) {
	function citation_social_buttons( $buttons_pos = 'floating' ) {

		$buttons        = array();
		$social_buttons = citation_get_settings( 'mts_social_buttons' );
		$layout         = citation_get_settings( 'social_button_layout' ) ? citation_get_settings( 'social_button_layout' ) : 'default';

		if ( null !== $social_buttons && is_array( $social_buttons ) && array_key_exists( 'enabled', $social_buttons ) ) {
			$buttons = $social_buttons['enabled'];
		}
		if ( ! empty( $buttons ) ) {
			switch ( $layout ) {
				case 'default':
					?>
						<div class="shareit shareit-default <?php echo $buttons_pos; ?>">
							<?php
							foreach ( $buttons as $key => $button ) {
								citation_social_button( $key );
							}
							?>
						</div>
					<?php
					break;

				case 'circular':
					?>
						<div class="shareit shareit-circular <?php echo $layout . ' ' . $buttons_pos; ?>">
							<?php
							foreach ( $buttons as $key => $button ) {
								citation_social_circular_button( $key );
							}
							?>
						</div>
					<?php
					break;

				case 'standard':
					?>
						<div class="shareit shareit-circular <?php echo $layout . ' ' . $buttons_pos; ?>">
							<?php
							foreach ( $buttons as $key => $button ) {
								citation_social_circular_button( $key );
							}
							?>
						</div>
					<?php
					break;

				default:
					?>
						<div class="shareit shareit-default <?php echo $buttons_pos; ?>">
							<?php
							foreach ( $buttons as $key => $button ) {
								citation_social_button( $key );
							}
							?>
						</div>
					<?php
					break;
			}
		}
	}
}
/**
 * Display network-independent sharing buttons.
 *
 * @param $button
 */
if ( ! function_exists( 'citation_social_button' ) ) {
	function citation_social_button( $button ) {
		$text = esc_html( get_the_title() );
		$link = urlencode( get_permalink() );
		switch ( $button ) {
			case 'facebookshare':
				?>
				<!-- Facebook Share-->
				<span class="share-item facebooksharebtn">
					<div class="fb-share-button" data-layout="button_count"></div>
				</span>
				<?php
				break;
			case 'twitter':
				?>
				<!-- Twitter -->
				<span class="share-item twitterbtn">
					<a href="https://twitter.com/share" class="twitter-share-button" data-via="<?php echo esc_attr( citation_get_settings( 'mts_twitter_username' ) ); ?>"><?php esc_html_e( 'Tweet', 'citation' ); ?></a>
				</span>
				<?php
				break;
			case 'facebook':
				?>
				<!-- Facebook -->
				<span class="share-item facebookbtn">
					<div id="fb-root"></div>
					<div class="fb-like" data-send="false" data-layout="button_count" data-width="150" data-show-faces="false"></div>
				</span>
				<?php
				break;
			case 'pinterest':
				?>
				<!-- Pinterest -->
				<span class="share-item pinbtn">
					<a href="http://pinterest.com/pin/create/button/?url=<?php the_permalink(); ?>&media=<?php $thumb = wp_get_attachment_image_src( get_post_thumbnail_id( get_the_ID() ), 'large' ); echo $thumb['0']; ?>&description=<?php the_title(); ?>" class="pin-it-button" count-layout="horizontal"><?php esc_html_e( 'Pin It', 'citation' ); ?></a>
				</span>
				<?php
				break;
			case 'linkedin':
				?>
				<!--Linkedin -->
				<span class="share-item linkedinbtn">
					<script type="IN/Share" data-url="<?php echo esc_url( get_the_permalink() ); ?>"></script>
				</span>
				<?php
				break;
			case 'reddit':
				?>
				<!-- Reddit -->
				<span class="share-item reddit">
					<a href="//www.reddit.com/submit" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;"> <img src="<?php echo get_template_directory_uri() . '/images/reddit.png'; ?>" alt=<?php _e( 'submit to reddit', 'citation' ); ?> border="0" /></a>
				</span>
				<?php
				break;
			case 'whatsapp':
				?>
				<!--WhatsApp -->
				<span class="share-item whatsapp">
					<a href="https://wa.me/?text=<?php echo $text . ' ' . $link; ?>" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;"><span class="icon"><i class="fa fa-whatsapp"></i></span><span class="social-text"><?php _e( 'WhatsApp', 'citation' ); ?></span></a>
				</span>
				<?php
				break;
			case 'telegram':
				?>
				<!-- Telegram -->
					<span class="share-item telegram">
						<a href="javascript:window.open('https://telegram.me/share/url?url='+encodeURIComponent(window.location.href), '_blank')"><span class="icon"><i class="fa fa-paper-plane"></i></span><span class="social-text"><?php _e( 'Telegram', 'citation' ); ?></span></a>
					</span>
				<?php
				break;
			case 'tumblr':
				?>
					<!-- Tumblr -->
					<span class="share-item tumblr">
						<a target="_blank" href="https://www.tumblr.com/widgets/share/tool?canonicalUrl=<?php echo $link; ?>&title=<?php echo $text; ?>"><span class="icon"><i class="fa fa-tumblr"></i></span><span class="social-text"><?php _e( 'Tumblr', 'citation' ); ?></span></a>
					</span>
				<?php
				break;
			case 'pocket':
				?>
					<!-- Pocket -->
					<span class="share-item pocket">
						<a target="_blank" href="https://getpocket.com/save?url=<?php echo $link; ?>&title=<?php echo $text; ?>"><span class="icon"><i class="fa fa-get-pocket"></i></span><span class="social-text"><?php _e( 'Pocket', 'citation' ); ?></span></a>
					</span>
				<?php
				break;
			case 'buffer':
				?>
				<!-- Buffer -->
					<span class="share-item buffer">
						<a target="_blank" href="https://bufferapp.com/add?url=<?php echo $link; ?>&amp;text=<?php echo $text; ?>"><span class="icon"><svg height="18px" id="Layer_1" style="enable-background:new 0 0 512 512;" version="1.1" viewBox="0 0 512 512" width="18px" xml:space="preserve" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><g><g><path d="M70.7,164.5l169.2,81.7c4.4,2.1,10.3,3.2,16.1,3.2s11.7-1.1,16.1-3.2l169.2-81.7c8.9-4.3,8.9-11.3,0-15.6L272.1,67.2    c-4.4-2.1-10.3-3.2-16.1-3.2s-11.7,1.1-16.1,3.2L70.7,148.9C61.8,153.2,61.8,160.2,70.7,164.5z"/><path d="M441.3,248.2c0,0-30.9-14.9-35-16.9s-5.2-1.9-9.5,0.1s-124.8,60.2-124.8,60.2c-4.5,2.1-10.3,3.2-16.1,3.2    s-11.7-1.1-16.1-3.2c0,0-117.3-56.6-122.8-59.3c-6-2.9-7.7-2.9-13.1-0.3c-5.6,2.7-33.4,16.1-33.4,16.1c-8.9,4.3-8.9,11.3,0,15.6    l169.2,81.7c4.4,2.1,10.3,3.2,16.1,3.2s11.7-1.1,16.1-3.2l169.2-81.7C450.2,259.5,450.2,252.5,441.3,248.2z"/></g><path d="M441.3,347.5c0,0-30.9-14.9-35-16.9s-5.2-1.9-9.5,0.1S272.1,391,272.1,391c-4.5,2.1-10.3,3.2-16.1,3.2s-11.7-1.1-16.1-3.2   c0,0-117.3-56.6-122.8-59.3c-6-2.9-7.7-2.9-13.1-0.3c-5.6,2.7-33.4,16.1-33.4,16.1c-8.9,4.3-8.9,11.3,0,15.6l169.2,81.7   c4.4,2.2,10.3,3.2,16.1,3.2s11.7-1.1,16.1-3.2l169.2-81.7C450.2,358.8,450.2,351.8,441.3,347.5z"/></g></svg></span><span class="social-text"><?php _e( 'Buffer', 'citation' ); ?></span></a>
					</span>
				<?php
				break;
			case 'vkontakte':
				?>
					<!-- Vkontakte -->
					<span class="share-item vkontakte">
						<a target="_blank" href="http://vk.com/share.php?url=<?php echo $link; ?>&title=<?php echo $text; ?>"><span class="icon"><i class="fa fa-vk"></i></span><span class="social-text"><?php _e( 'VK', 'citation' ); ?></span></a>
					</span>
				<?php
				break;
			case 'mix':
				?>
					<!-- Mix -->
					<span class="share-item mix">
						<a target="_blank" href="https://mix.com/add?url=<?php echo $link; ?>"><span class="icon"><svg height="18px" style="enable-background:new 0 0 512 512;" version="1.1" viewBox="0 0 512 512" width="18px" xml:space="preserve" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><g id="comp_x5F_217-mix"><g><path d="M26.001,54.871v358.246c0,57.705,90.357,59.656,90.357,0V168.124c8.11-54.316,90.357-51.749,90.357,6.675v179.994    c0,59.453,98.57,59.556,98.57,0V235.584c5.44-56.166,90.357-53.906,90.357,4.415v24.44c0,61.503,90.355,58.114,90.355,0V54.871    H26.001z"/></g></g><g id="Layer_1"/></svg></span><span class="social-text"><?php _e( 'Mix', 'citation' ); ?></span></a>
					</span>
				<?php
				break;
		}
	}
}
/**
 * Display network-independent sharing buttons.
 *
 * @param $button
 */
if ( ! function_exists( 'citation_social_circular_button' ) ) {
	function citation_social_circular_button( $button ) {
		global $post;
		$text = esc_html( get_the_title() );
		$link = urlencode( get_permalink() );
		if ( is_single() ) {
			$img_url = '';
			$img     = '';
			if ( has_post_thumbnail( $post->ID ) ) {
				$img     = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'citation-featuredfull' );
				$img_url = $img[0];
			}
		}
		switch ( $button ) {
			case 'facebookshare':
				?>
				<!-- Facebook -->
				<a href="//www.facebook.com/share.php?m2w&s=100&p[url]=<?php echo urlencode( get_permalink() ); ?>&p[images][0]=<?php echo urlencode( $img_url[0] ); ?>&p[title]=<?php echo urlencode( get_the_title() ); ?>&u=<?php echo urlencode( get_permalink() ); ?>&t=<?php echo urlencode( get_the_title() ); ?>" class="facebooksharebtn" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;"><span class="social-icon"><i class="fa fa-facebook-official"></i></span></a>
				<?php
				break;
			case 'twitter':
				?>
				<!-- Twitter -->
				<?php
				$via = '';
				if ( citation_get_settings( 'mts_twitter_username' ) ) {
					$via = '&via=' . citation_get_settings( 'mts_twitter_username' );
				}
				?>
				<a href="https://twitter.com/intent/tweet?original_referer=<?php echo urlencode( get_permalink() ); ?>&text=<?php echo get_the_title(); ?>&url=<?php echo urlencode( get_permalink() ); ?><?php echo $via; ?>" class="twitterbutton" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;"><span class="social-icon"><i class="fa fa-twitter"></i></span></a>
				<?php
				break;

			case 'pinterest':
				global $post;
				?>
				<!-- Pinterest -->
				<?php $pinterestimage = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'full' ); ?>
				<a href="http://pinterest.com/pin/create/button/?url=<?php echo urlencode( get_permalink( $post->ID ) ); ?>&media=<?php echo $pinterestimage[0]; ?>&description=<?php the_title(); ?>" class="share-pinbtn" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;"><span class="social-icon"><i class="fa fa-pinterest"></i></span></a>
				<?php
				break;
			case 'linkedin':
				?>
				<!--Linkedin -->
				<a href="//www.linkedin.com/shareArticle?mini=true&url=<?php echo urlencode( get_permalink() ); ?>&title=<?php echo get_the_title(); ?>&source=<?php echo 'url'; ?>" class="linkedinbtn" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;"><span class="social-icon"><i class="fa fa-linkedin"></i></span><span class="social-text"><?php _e( 'Share', 'citation' ); ?></span></a>
				<?php
				break;
			case 'reddit':
				?>
				<!-- Reddit -->
				<a href="//www.reddit.com/submit" class="reddit" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;"><span class="social-icon"><i class="fa fa-reddit-alien"></i></span></a>
				<?php
				break;
			case 'whatsapp':
				?>
				<!--WhatsApp -->
				<a href="https://wa.me/?text=<?php echo $text . ' ' . $link; ?>" class="whatsapp" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;"><span class="social-icon"><i class="fa fa-whatsapp"></i></span></a>
				<?php
				break;
			case 'telegram':
				?>
				<!-- Telegram -->
				<a href="javascript:window.open('https://telegram.me/share/url?url='+encodeURIComponent(window.location.href), '_blank')" class="telegram"><span class="social-icon"><i class="fa fa-paper-plane"></i></span></a>
				<?php
				break;
			case 'tumblr':
				?>
				<!-- Tumblr -->
				<a target="_blank" href="https://www.tumblr.com/widgets/share/tool?canonicalUrl=<?php echo $link; ?>&title=<?php echo $text; ?>" class="tumblr"><span class="social-icon"><i class="fa fa-tumblr"></i></span></a>
				<?php
				break;
			case 'pocket':
				?>
				<!-- Pocket -->
				<a target="_blank" href="https://getpocket.com/save?url=<?php echo $link; ?>&title=<?php echo $text; ?>" class="pocket"><span class="social-icon"><i class="fa fa-get-pocket"></i></span></a>
				<?php
				break;
			case 'buffer':
				?>
				<!-- Buffer -->
				<a target="_blank" href="https://bufferapp.com/add?url=<?php echo $link; ?>&amp;text=<?php echo $text; ?>" class="buffer"><span class="social-icon"><svg height="18px" id="Layer_1" style="enable-background:new 0 0 512 512;" version="1.1" viewBox="0 0 512 512" width="18px" xml:space="preserve" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><g><g><path d="M70.7,164.5l169.2,81.7c4.4,2.1,10.3,3.2,16.1,3.2s11.7-1.1,16.1-3.2l169.2-81.7c8.9-4.3,8.9-11.3,0-15.6L272.1,67.2    c-4.4-2.1-10.3-3.2-16.1-3.2s-11.7,1.1-16.1,3.2L70.7,148.9C61.8,153.2,61.8,160.2,70.7,164.5z"/><path d="M441.3,248.2c0,0-30.9-14.9-35-16.9s-5.2-1.9-9.5,0.1s-124.8,60.2-124.8,60.2c-4.5,2.1-10.3,3.2-16.1,3.2    s-11.7-1.1-16.1-3.2c0,0-117.3-56.6-122.8-59.3c-6-2.9-7.7-2.9-13.1-0.3c-5.6,2.7-33.4,16.1-33.4,16.1c-8.9,4.3-8.9,11.3,0,15.6    l169.2,81.7c4.4,2.1,10.3,3.2,16.1,3.2s11.7-1.1,16.1-3.2l169.2-81.7C450.2,259.5,450.2,252.5,441.3,248.2z"/></g><path d="M441.3,347.5c0,0-30.9-14.9-35-16.9s-5.2-1.9-9.5,0.1S272.1,391,272.1,391c-4.5,2.1-10.3,3.2-16.1,3.2s-11.7-1.1-16.1-3.2   c0,0-117.3-56.6-122.8-59.3c-6-2.9-7.7-2.9-13.1-0.3c-5.6,2.7-33.4,16.1-33.4,16.1c-8.9,4.3-8.9,11.3,0,15.6l169.2,81.7   c4.4,2.2,10.3,3.2,16.1,3.2s11.7-1.1,16.1-3.2l169.2-81.7C450.2,358.8,450.2,351.8,441.3,347.5z"/></g></svg></span></a>
				<?php
				break;
			case 'vkontakte':
				?>
				<!-- Vkontakte -->
				<a target="_blank" href="http://vk.com/share.php?url=<?php echo $link; ?>&title=<?php echo $text; ?>" class="vkontakte"><span class="social-icon"><i class="fa fa-vk"></i></span></a>
				<?php
				break;
			case 'mix':
				?>
				<!-- Mix -->
				<a target="_blank" href="https://mix.com/add?url=<?php echo $link; ?>" class="mix"><span class="social-icon"><svg height="18px" style="enable-background:new 0 0 512 512;" version="1.1" viewBox="0 0 512 512" width="18px" xml:space="preserve" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><g id="comp_x5F_217-mix"><g><path d="M26.001,54.871v358.246c0,57.705,90.357,59.656,90.357,0V168.124c8.11-54.316,90.357-51.749,90.357,6.675v179.994    c0,59.453,98.57,59.556,98.57,0V235.584c5.44-56.166,90.357-53.906,90.357,4.415v24.44c0,61.503,90.355,58.114,90.355,0V54.871    H26.001z"/></g></g><g id="Layer_1"/></svg></span></a>
				<?php
				break;
		}
	}
}

/**
 * Display a post of specific layout.
 *
 * @param string $layout
 */
if ( ! function_exists( 'citation_blog_articles' ) ) {
	function citation_blog_articles() {
		?>
		<article class="latestPost excerpt">
			<a href="<?php echo esc_url( get_the_permalink() ); ?>" title="<?php the_title_attribute(); ?>" id="featured-thumbnail" class="post-image post-image-left <?php echo 'layout-default'; ?>">
				<div class="featured-thumbnail">
					<?php
					if ( has_post_thumbnail() ) {
						the_post_thumbnail( 'citation-layout-2', array( 'title' => '' ) );
					} else {
						echo '<img src="' . get_template_directory_uri() . '/images/nothumb-citation-featured.png" alt="' . __( 'No Preview', 'citation' ) . '"  class="wp-post-image" />';
					}
					?>
				</div>
				<?php
				if ( function_exists( 'wp_review_show_total' ) ) {
					wp_review_show_total( true, 'latestPost-review-wrapper' );
				}
				?>
			</a>
			<div class="wrapper">
				<header>
					<?php citation_the_post_meta( 'archive' ); ?>
					<h2 class="title front-view-title"><a href="<?php echo esc_url( get_the_permalink() ); ?>" title="<?php the_title_attribute(); ?>"><?php the_title(); ?></a></h2>
				</header>
				<div class="front-view-content">
					<?php
					if ( empty( citation_excerpt() ) ) {
						echo citation_truncate( get_the_content(), citation_get_settings( 'archive_excerpt' ), 'words' );
					} else {
						echo citation_excerpt( citation_get_settings( 'archive_excerpt' ) );
					}
					?>
				</div>
				<?php
				if ( citation_get_settings( 'archive_readmore_button' ) ) :
					citation_readmore();
				endif;
				?>
			</div>
		</article>
		<?php
	}
}

/**
 * Get Single meta info
 */
function get_single_metainfo( $section = 'single' ) {
	$single_meta_info = citation_get_settings( 'mts_' . $section . '_headline_meta_info' );
	if ( isset( $single_meta_info['category'] ) || isset( $single_meta_info['time'] ) || isset( $single_meta_info['date'] ) || isset( $single_meta_info['authorpic'] ) || isset( $single_meta_info['author'] ) || isset( $single_meta_info['comment'] ) ) :
		?>
		<div class="post-info">
			<?php
			if ( isset( $single_meta_info['authorpic'] ) ) :
				?>
				<span class="theauthorimage"><?php echo get_avatar( get_the_author_meta( 'email' ), 40 ); ?></span>
				<?php
			endif;
			if ( isset( $single_meta_info['author'] ) ) :
				printf( '<span class="theauthor">%s</span>', get_the_author_posts_link() );
			endif;
			if ( isset( $single_meta_info['date'] ) ) :
				?>
				<span class="thetime date updated"><span><?php echo get_the_time( get_option( 'date_format' ) ); ?></span></span>
				<?php
			endif;
			if ( isset( $single_meta_info['comment'] ) ) :
				printf( '<span class="thecomment">%s</span>', get_comments_number_text() );
			endif;
			?>
		</div>
		<?php
	endif;
}

/**
 * Display Instagram feeds.
 *
 * returns a big old hunk of JSON from a non-private IG account page.
 *
 * @param string $layout
 */
function scrape_insta( $username ) {
	$request         = wp_remote_get( 'http://instagram.com/' . $username );
	$insta_source    = wp_remote_retrieve_body( $request );
	$shards          = explode( 'window._sharedData = ', $insta_source );
	$insta_json      = explode( ';</script>', $shards[1] );
	$insta_array     = json_decode( $insta_json[0], true );
	$update_interval = apply_filters( 'citation_instagram_update_interval', 3600 );
	$insta_serialize = serialize( $insta_array );
	set_transient( 'citation_instagram_' . $username, $insta_serialize, $update_interval );
	return $insta_array;
}
if ( ! function_exists( 'citation_instagram' ) ) {

	function citation_instagram( $username, $number, $force_recitation = false ) {
		$results_serialized = get_transient( 'citation_instagram_' . $username );
		if ( false === $results_serialized ) {
			$results_array = scrape_insta( $username );
		} else {
			$results_array = unserialize( $results_serialized );
		}
		for ( $i = 0; $i < $number; $i++ ) {
			if ( isset( $results_array['entry_data']['ProfilePage'][0]['graphql']['user']['edge_owner_to_timeline_media']['edges'][ $i ] ) ) {
				$latest_array = $results_array['entry_data']['ProfilePage'][0]['graphql']['user']['edge_owner_to_timeline_media']['edges'][ $i ];
				if ( $latest_array['node']['is_video'] ) {
					echo '<a href="http://instagram.com/p/' . $latest_array['node']['shortcode'] . '" target="_blank"><div style="background-image:url(' . preg_replace( '/vp.*\/.{32}\/.{8}\//', '', $latest_array['node']['thumbnail_resources'][2]['src'] ) . ');"></div></a>';
				} else {
					echo '<a href="http://instagram.com/p/' . $latest_array['node']['shortcode'] . '" target="_blank"><div style="background-image:url(' . $latest_array['node']['thumbnail_resources'][2]['src'] . ');"></div></a>';
				}
			}
		}

	}
}

/**
 * Detect Adblocker Notice
 *
 * @return blocker-notice box
 */
function detect_adblocker_notice() {
?>
	<div class="blocker-notice">
		<i class="fa fa-exclamation"></i>
		<h4><?php echo citation_get_settings( 'detect_adblocker_title' ); ?></h4>
		<p><?php echo citation_get_settings( 'detect_adblocker_description' ); ?></p>
		<div><a href="" class="recitation-button"><?php esc_html_e( 'Recitation', 'citation' ); ?></a></div>
	</div>
<?php
}

/**
 * Display Header social icons
 * @param  array  $data
 * @return html
 */
function citation_header_social_icons( $data = array(), $echo = false ) {

	if ( empty( $data ) ) {
		return;
	}

	$out = '<div class="header-social-icons">';
	foreach ( $data as $item ) {
		$out .= sprintf(
			'<a href="%1$s" title="%2$s" class="header-%3$s" target="_blank"><span class="fa fa-%3$s"></span></a>',
			$item['header_icon_link'],
			$item['header_icon_title'],
			$item['header_icon']
		);
	}

	$out .= '</div>';

	if ( $echo ) {
		echo $out;
	} else {
		return $out;
	}
}

/**
 * Show header ad
 *
 */
function show_header_ad() {

	global $template;

	$template = basename( $template );
	$page     = citation_get_settings( 'header_adcode_show' );

	$hash = [
		'all'    => true,
		'home'   => 'page-home.php' === $template,
		'blog'   => is_home() && 'page-home.php' !== $template,
		'single' => is_single(),
		'page'   => is_page() && 'page-home.php' !== $template,
		'both'   => is_home() || is_single(),
	];

	if ( isset( $hash[ $page ] ) && $hash[ $page ] ) {
		get_template_part( 'template-parts/header/header', 'adcode' );
	}

}

function citation_featured_layouts() {
	include_once get_parent_theme_file_path( 'includes/class-citation-featured-layouts.php' );
	citation()->featured_layouts = new Citation_Featured_Layouts;
	citation()->featured_layouts->render();
}
function citation_single_sections() {
	include_once get_parent_theme_file_path( 'includes/class-citation-single-sections.php' );
	citation()->single_sections = new Citation_Single_Sections;
	citation()->single_sections->render();
}

// HomePage Sections.
function citation_homepage_sections() {
	$options = citation_get_settings( 'homepage_layout' );
	if ( ! is_array( $options ) || ! array_key_exists( 'enabled', $options ) ) {
		return;
	}

	foreach ( $options['enabled'] as $template => $section ) {
		get_template_part( 'template-parts/homepage/home', $template );
	}
}
