<?php
/**
 * HomePage Posts
 *
 * @package Citation
 */

$features = citation_get_settings( 'featured_categories' );
if ( empty( $features ) ) {
	return;
}
foreach ( $features as $feature ) :
	$title        = isset( $feature['mts_featured_title'] ) ? $feature['mts_featured_title'] : 'No Title';
	$posts_layout = isset( $feature['blog_layout'] ) ? $feature['blog_layout'] : '';
	if ( 'layout-default' === $posts_layout ) {
		$posts_layout = 'default';
	}
	$unique_id = isset( $feature['unique_id'] ) ? $feature['unique_id'] : '';

	$menus['blog']['child'][ 'blog-' . $unique_id ] = array(
		'title' => $title,
		// translators: description.
		'desc'  => sprintf( wp_kses_post( __( 'From here, you can control the elements of %s', 'citation' ) ), $title ),
	);

	// Dependency check that back to top option is enable.
	$post_title_dependency = array(
		'relation' => 'and',
		array(
			'field'      => 'featured_category_title_' . $unique_id,
			'value'      => '1',
			'comparison' => '==',
		),
	);

	$readmore = array(
		'relation' => 'and',
		array(
			'field'      => 'readmore_' . $unique_id,
			'value'      => '1',
			'comparison' => '==',
		),
	);

	$sections[ 'blog-' . $unique_id ] = array(

		/**
		 * Layout Default Settings
		 *
		 * @package Citation
		 */

		// Section Title.
		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Section Title', 'citation' ),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'featured_category_title_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Title', 'citation' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide title of post container.', 'citation' ),
			'std'      => '0',
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'post_title_alignment_' . $unique_id,
			'type'       => 'button_set',
			'title'      => esc_html__( 'Section Title Alignment', 'citation' ),
			'sub_desc'   => esc_html__( 'Choose the section title alignment', 'citation' ),
			'options'    => array(
				'left'   => esc_html__( 'Left', 'citation' ),
				'center' => esc_html__( 'Center', 'citation' ),
				'right'  => esc_html__( 'Right', 'citation' ),
			),
			'std'        => 'center',
			'dependency' => $post_title_dependency,
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_background_' . $unique_id,
			'type'       => 'background',
			'title'      => esc_html__( 'Post Title Background Color', 'citation' ),
			'sub_desc'   => esc_html__( 'Set background color, pattern and image from here.', 'citation' ),
			'options'    => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'        => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_margin_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Margin', 'citation' ),
			'sub_desc'   => esc_html__( 'Set section title margin from here.', 'citation' ),
			'std'        => array(
				'top'    => citation_px_to_rem( '20px' ),
				'right'  => '0',
				'bottom' => citation_px_to_rem( '45px' ),
				'left'   => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Padding', 'citation' ),
			'sub_desc'   => esc_html__( 'Set section title padding from here.', 'citation' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'post_title_border_' . $unique_id,
			'type'       => 'border',
			'title'      => esc_html__( 'Border', 'citation' ),
			'sub_desc'   => esc_html__( 'Select border', 'citation' ),
			'dependency' => $post_title_dependency,
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Section Title Typography', 'citation' ),
			'std'        => array(
				'preview-text'  => 'Title Font',
				'preview-color' => 'light',
				'font-family'   => 'Raleway',
				'font-weight'   => '300',
				'font-size'     => '32px',
				'line-height'   => '1.2',
				'line-height'   => '1.2',
				'color'         => '#363a60',
				'css-selectors' => '.title-container.title-id-' . $unique_id . ' h3.featured-category-title',
			),
			'dependency' => $post_title_dependency,
		) : null,

		// Meta info.
		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'citation' ),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'mts_home_headline_meta_info' . $unique_id,
			'type'     => 'layout2',
			// translators: title.
			'title'    => sprintf( wp_kses_post( __( '%s Meta Info', 'citation' ) ), $title ),
			// translators: description.
			'sub_desc' => sprintf( wp_kses_post( __( 'Organize how you want the post meta info to appear on %s', 'citation' ) ), $title ),
			'options'  => array(
				'enabled'  => array(),
				'disabled' => array(
					'author'   => array(
						'label'     => __( 'Author Name', 'citation' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'citation' ),
							),
						),
					),
					'date'     => array(
						'label'     => esc_html__( 'Date', 'citation' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'citation' ),
							),
						),
					),
					'category' => array(
						'label'     => esc_html__( 'Categories', 'pets' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_category_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'pets' ),
							),
						),
					),
					'comment'  => array(
						'label'     => esc_html__( 'Comment Count', 'citation' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'citation' ),
							),
						),
					),
				),
			),
			'std'      => array(
				'enabled'  => array(),
				'disabled' => array(
					'author'   => array(
						'label'     => __( 'Author Name', 'citation' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'citation' ),
							),
						),
					),
					'date'     => array(
						'label'     => esc_html__( 'Date', 'citation' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'citation' ),
							),
						),
					),
					'category' => array(
						'label'     => esc_html__( 'Categories', 'pets' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_category_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'pets' ),
							),
						),
					),
					'comment'  => array(
						'label'     => esc_html__( 'Comment Count', 'citation' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'citation' ),
							),
						),
					),
				),
			),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'meta_info_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'citation' ),
			'sub_desc' => esc_html__( 'Select border.', 'citation' ),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'    => 'meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Meta Info Typography', 'citation' ),
			'std'   => array(
				'preview-text'  => 'Post Meta Info Font',
				'preview-color' => 'light',
				'font-family'   => 'Raleway',
				'font-weight'   => '400',
				'font-size'     => '14px',
				'margin-bottom' => citation_px_to_rem( '20px' ),
				'color'         => '#363a60',
				'line-height'   => '2',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .post-info, .layout-' . $unique_id . ' .latestPost .post-info a',
			),
		) : null,

		// Read More Button.
		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_readmore_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Read More Button', 'citation' ),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'       => 'readmore_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Enable/Disable Read More', 'citation' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide Read More.', 'citation' ),
			'std'      => '1',
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'readmore_text_' . $unique_id,
			'type'       => 'text',
			'title'      => esc_html__( 'Button Text', 'citation' ),
			'std'        => 'Read More',
			'dependency' => $readmore,
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'readmore_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Button Font', 'digital' ),
			'std'        => array(
				'preview-text'  => 'Read More Font',
				'preview-color' => 'light',
				'font-family'   => 'Raleway',
				'font-weight'   => '700',
				'font-size'     => '11px',
				'color'         => '#363a60',
				'css-selectors' => '.layout-' . $unique_id . ' .readMore a',
			),
			'dependency' => $readmore,
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'readmore_bg_color_' . $unique_id,
			'type'       => 'color',
			'title'      => esc_html__( 'Button Background Color', 'citation' ),
			'std'        => '#ffffff',
			'dependency' => $readmore,
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'readmore_border_' . $unique_id,
			'type'       => 'border',
			'title'      => esc_html__( 'Button Border', 'citation' ),
			'sub_desc'   => esc_html__( 'Select border.', 'citation' ),
			'std'        => array(
				'direction' => 'all',
				'size'      => '1',
				'style'     => 'solid',
				'color'     => '#363a60',
			),
			'dependency' => $readmore,
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'readmore_bg_hover_color_' . $unique_id,
			'type'       => 'color',
			'title'      => esc_html__( 'Button Background Hover Color', 'citation' ),
			'std'        => '#ffffff',
			'dependency' => $readmore,
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'readmore_hover_color_' . $unique_id,
			'type'       => 'color',
			'title'      => esc_html__( 'Button Hover Color', 'citation' ),
			'std'        => citation_get_settings( 'primary_color_scheme' ),
			'dependency' => $readmore,
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'readmore_border_hover_color_' . $unique_id,
			'type'       => 'color',
			'title'      => esc_html__( 'Button Border Hover Color', 'citation' ),
			'std'        => citation_get_settings( 'primary_color_scheme' ),
			'dependency' => $readmore,
		) : null,
		// Post Container.
		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'citation' ),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'citation' ),
			'sub_desc' => esc_html__( 'Select border', 'citation' ),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'citation' ),
			'sub_desc' => esc_html__( 'Post margin.', 'citation' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => citation_px_to_rem( '122px' ),
				'bottom' => '0',
			),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'citation' ),
			'sub_desc' => esc_html__( 'Post padding.', 'citation' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Title Font', 'citation' ),
			'std'   => array(
				'preview-text'  => 'Post Title Font',
				'preview-color' => 'light',
				'font-family'   => 'Raleway',
				'font-weight'   => '700',
				'font-size'     => '18px',
				'line-height'   => '1.333',
				'margin-bottom' => citation_px_to_rem( '16px' ),
				'color'         => '#363a60',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .title a',
			),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_excerpt_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Excerpt Font', 'citation' ),
			'std'   => array(
				'preview-text'  => 'Post Excerpt Font',
				'preview-color' => 'light',
				'font-family'   => 'Raleway',
				'font-weight'   => '400',
				'font-size'     => '14px',
				'margin-bottom' => citation_px_to_rem( '22px' ),
				'line-height'   => '1.5',
				'color'         => '#363a60',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .front-view-content',
			),
		) : null,

		/**
		 * Layout 1 Settings
		 *
		 * @package Citation
		 */

		// Section Title.
		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'post_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Section Title', 'citation' ),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'featured_category_title_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Title', 'citation' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide title of post container.', 'citation' ),
			'std'      => '1',
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'post_title_alignment_' . $unique_id,
			'type'       => 'button_set',
			'title'      => esc_html__( 'Section Title Alignment', 'citation' ),
			'sub_desc'   => esc_html__( 'Choose the section title alignment', 'citation' ),
			'options'    => array(
				'left'   => esc_html__( 'Left', 'citation' ),
				'center' => esc_html__( 'Center', 'citation' ),
				'right'  => esc_html__( 'Right', 'citation' ),
			),
			'std'        => 'center',
			'dependency' => $post_title_dependency,
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_background_' . $unique_id,
			'type'       => 'background',
			'title'      => esc_html__( 'Post Title Background Color', 'citation' ),
			'sub_desc'   => esc_html__( 'Set background color, pattern and image from here.', 'citation' ),
			'options'    => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'        => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_margin_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Margin', 'citation' ),
			'sub_desc'   => esc_html__( 'Set section title margin from here.', 'citation' ),
			'std'        => array(
				'top'    => citation_px_to_rem( '20px' ),
				'right'  => '0',
				'bottom' => citation_px_to_rem( '45px' ),
				'left'   => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Padding', 'citation' ),
			'sub_desc'   => esc_html__( 'Set section title padding from here.', 'citation' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'post_title_border_' . $unique_id,
			'type'       => 'border',
			'title'      => esc_html__( 'Border', 'citation' ),
			'sub_desc'   => esc_html__( 'Select border', 'citation' ),
			'dependency' => $post_title_dependency,
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Section Title Typography', 'citation' ),
			'std'        => array(
				'preview-text'  => 'Title Font',
				'preview-color' => 'light',
				'font-family'   => 'Raleway',
				'font-weight'   => '300',
				'font-size'     => '32px',
				'line-height'   => '1.2',
				'color'         => '#363a60',
				'css-selectors' => '.title-container.title-id-' . $unique_id . ' h3.featured-category-title',
			),
			'dependency' => $post_title_dependency,
		) : null,

		// Meta info.
		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'citation' ),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'mts_home_headline_meta_info' . $unique_id,
			'type'     => 'layout2',
			// translators: title.
			'title'    => sprintf( wp_kses_post( __( '%s Meta Info', 'citation' ) ), $title ),
			// translators: description.
			'sub_desc' => sprintf( wp_kses_post( __( 'Organize how you want the post meta info to appear on %s', 'citation' ) ), $title ),
			'options'  => array(
				'enabled'  => array(),
				'disabled' => array(
					'author'   => array(
						'label'     => __( 'Author Name', 'citation' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'citation' ),
							),
						),
					),
					'date'     => array(
						'label'     => esc_html__( 'Date', 'citation' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'citation' ),
							),
						),
					),
					'category' => array(
						'label'     => esc_html__( 'Categories', 'pets' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_category_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'pets' ),
							),
						),
					),
					'comment'  => array(
						'label'     => esc_html__( 'Comment Count', 'citation' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'citation' ),
							),
						),
					),
				),
			),
			'std'      => array(
				'enabled'  => array(),
				'disabled' => array(
					'author'   => array(
						'label'     => __( 'Author Name', 'citation' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'citation' ),
							),
						),
					),
					'date'     => array(
						'label'     => esc_html__( 'Date', 'citation' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'citation' ),
							),
						),
					),
					'category' => array(
						'label'     => esc_html__( 'Categories', 'pets' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_category_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'pets' ),
							),
						),
					),
					'comment'  => array(
						'label'     => esc_html__( 'Comment Count', 'citation' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'citation' ),
							),
						),
					),
				),
			),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'meta_info_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'citation' ),
			'sub_desc' => esc_html__( 'Select border.', 'citation' ),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Meta Info Typography', 'citation' ),
			'std'   => array(
				'preview-text'  => 'Post Meta Info Font',
				'preview-color' => 'light',
				'font-family'   => 'Raleway',
				'font-weight'   => '400',
				'font-size'     => '14px',
				'margin-bottom' => citation_px_to_rem( '20px' ),
				'color'         => '#363a60',
				'line-height'   => '2',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .post-info, .layout-' . $unique_id . ' .latestPost .post-info a',
			),
		) : null,

		// Read More Button.
		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'post_readmore_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Read More Button', 'citation' ),
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'readmore_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Enable/Disable Read More', 'citation' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide Read More.', 'citation' ),
			'std'      => '1',
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'readmore_text_' . $unique_id,
			'type'       => 'text',
			'title'      => esc_html__( 'Button Text', 'citation' ),
			'std'        => 'Read More',
			'dependency' => $readmore,
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'readmore_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Button Font', 'digital' ),
			'std'        => array(
				'preview-text'  => 'Read More Font',
				'preview-color' => 'dark',
				'font-family'   => 'Raleway',
				'font-weight'   => '700',
				'font-size'     => '13px',
				'color'         => '#ffffff',
				'margin-top'    => citation_px_to_rem( '70px' ),
				'css-selectors' => '.layout-' . $unique_id . ' .readMore a',
			),
			'dependency' => $readmore,
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'readmore_bg_color_' . $unique_id,
			'type'       => 'color',
			'title'      => esc_html__( 'Button Background Color', 'citation' ),
			'std'        => citation_get_settings( 'primary_color_scheme' ),
			'dependency' => $readmore,
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'readmore_border_' . $unique_id,
			'type'       => 'border',
			'title'      => esc_html__( 'Button Border', 'citation' ),
			'sub_desc'   => esc_html__( 'Select border.', 'citation' ),
			'std'        => array(
				'direction' => 'all',
				'size'      => '1',
				'style'     => 'solid',
				'color'     => citation_get_settings( 'primary_color_scheme' ),
			),
			'dependency' => $readmore,
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'readmore_bg_hover_color_' . $unique_id,
			'type'       => 'color',
			'title'      => esc_html__( 'Button Background Hover Color', 'citation' ),
			'std'        => '#f83682',
			'dependency' => $readmore,
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'readmore_hover_color_' . $unique_id,
			'type'       => 'color',
			'title'      => esc_html__( 'Button Hover Color', 'citation' ),
			'std'        => '#ffffff',
			'dependency' => $readmore,
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'readmore_border_hover_color_' . $unique_id,
			'type'       => 'color',
			'title'      => esc_html__( 'Button Border Hover Color', 'citation' ),
			'std'        => '#f83682',
			'dependency' => $readmore,
		) : null,
		// Post Container.
		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'citation' ),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'citation' ),
			'sub_desc' => esc_html__( 'Select border', 'citation' ),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'citation' ),
			'sub_desc' => esc_html__( 'Post margin.', 'citation' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => citation_px_to_rem( '65px' ),
				'bottom' => '0',
			),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'citation' ),
			'sub_desc' => esc_html__( 'Post padding.', 'citation' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'post_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Title Font', 'citation' ),
			'std'   => array(
				'preview-text'  => 'Post Title Font',
				'preview-color' => 'light',
				'font-family'   => 'Raleway',
				'font-weight'   => '600',
				'font-size'     => '24px',
				'line-height'   => '1.25',
				'margin-bottom' => citation_px_to_rem( '18px' ),
				'color'         => '#363a60',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .title a',
			),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'post_excerpt_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Excerpt Font', 'citation' ),
			'std'   => array(
				'preview-text'  => 'Post Excerpt Font',
				'preview-color' => 'light',
				'font-family'   => 'Raleway',
				'font-weight'   => '400',
				'font-size'     => '14px',
				'margin-bottom' => citation_px_to_rem( '16px' ),
				'line-height'   => '2',
				'color'         => '#363a60',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .front-view-content',
			),
		) : null,

		/**
		 * Layout 1 Settings
		 *
		 * @package Citation
		 */

		// Section Title.
		( 'layout-2' === $posts_layout ) ? array(
			'id'    => 'post_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Section Title', 'citation' ),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'featured_category_title_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Title', 'citation' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide title of post container.', 'citation' ),
			'std'      => '1',
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'post_title_alignment_' . $unique_id,
			'type'       => 'button_set',
			'title'      => esc_html__( 'Section Title Alignment', 'citation' ),
			'sub_desc'   => esc_html__( 'Choose the section title alignment', 'citation' ),
			'options'    => array(
				'left'   => esc_html__( 'Left', 'citation' ),
				'center' => esc_html__( 'Center', 'citation' ),
				'right'  => esc_html__( 'Right', 'citation' ),
			),
			'std'        => 'center',
			'dependency' => $post_title_dependency,
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_background_' . $unique_id,
			'type'       => 'background',
			'title'      => esc_html__( 'Post Title Background Color', 'citation' ),
			'sub_desc'   => esc_html__( 'Set background color, pattern and image from here.', 'citation' ),
			'options'    => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'        => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_margin_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Margin', 'citation' ),
			'sub_desc'   => esc_html__( 'Set section title margin from here.', 'citation' ),
			'std'        => array(
				'top'    => citation_px_to_rem( '20px' ),
				'right'  => '0',
				'bottom' => citation_px_to_rem( '45px' ),
				'left'   => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Padding', 'citation' ),
			'sub_desc'   => esc_html__( 'Set section title padding from here.', 'citation' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'post_title_border_' . $unique_id,
			'type'       => 'border',
			'title'      => esc_html__( 'Border', 'citation' ),
			'sub_desc'   => esc_html__( 'Select border', 'citation' ),
			'dependency' => $post_title_dependency,
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Section Title Typography', 'citation' ),
			'std'        => array(
				'preview-text'  => 'Title Font',
				'preview-color' => 'light',
				'font-family'   => 'Raleway',
				'font-weight'   => '300',
				'font-size'     => '32px',
				'line-height'   => '1.2',
				'color'         => '#363a60',
				'css-selectors' => '.title-container.title-id-' . $unique_id . ' h3.featured-category-title',
			),
			'dependency' => $post_title_dependency,
		) : null,

		// Meta info.
		( 'layout-2' === $posts_layout ) ? array(
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'citation' ),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'mts_home_headline_meta_info' . $unique_id,
			'type'     => 'layout2',
			// translators: title.
			'title'    => sprintf( wp_kses_post( __( '%s Meta Info', 'citation' ) ), $title ),
			// translators: description.
			'sub_desc' => sprintf( wp_kses_post( __( 'Organize how you want the post meta info to appear on %s', 'citation' ) ), $title ),
			'options'  => array(
				'enabled'  => array(),
				'disabled' => array(
					'author'   => array(
						'label'     => __( 'Author Name', 'citation' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'citation' ),
							),
						),
					),
					'date'     => array(
						'label'     => esc_html__( 'Date', 'citation' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'citation' ),
							),
						),
					),
					'category' => array(
						'label'     => esc_html__( 'Categories', 'pets' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_category_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'pets' ),
							),
						),
					),
					'comment'  => array(
						'label'     => esc_html__( 'Comment Count', 'citation' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'citation' ),
							),
						),
					),
				),
			),
			'std'      => array(
				'enabled'  => array(),
				'disabled' => array(
					'author'   => array(
						'label'     => __( 'Author Name', 'citation' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'citation' ),
							),
						),
					),
					'date'     => array(
						'label'     => esc_html__( 'Date', 'citation' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'citation' ),
							),
						),
					),
					'category' => array(
						'label'     => esc_html__( 'Categories', 'pets' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_category_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'pets' ),
							),
						),
					),
					'comment'  => array(
						'label'     => esc_html__( 'Comment Count', 'citation' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'citation' ),
							),
						),
					),
				),
			),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'meta_info_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'citation' ),
			'sub_desc' => esc_html__( 'Select border.', 'citation' ),
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'    => 'meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Meta Info Typography', 'citation' ),
			'std'   => array(
				'preview-text'  => 'Post Meta Info Font',
				'preview-color' => 'light',
				'font-family'   => 'Raleway',
				'font-weight'   => '400',
				'font-size'     => '14px',
				'margin-bottom' => citation_px_to_rem( '20px' ),
				'color'         => '#363a60',
				'line-height'   => '2',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .post-info, .layout-' . $unique_id . ' .latestPost .post-info a',
			),
		) : null,
		// Read More Button.
		( 'layout-2' === $posts_layout ) ? array(
			'id'    => 'post_readmore_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Read More Button', 'citation' ),
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'readmore_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Enable/Disable Read More', 'citation' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide Read More.', 'citation' ),
			'std'      => '1',
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'readmore_text_' . $unique_id,
			'type'       => 'text',
			'title'      => esc_html__( 'Button Text', 'citation' ),
			'std'        => 'Read More',
			'dependency' => $readmore,
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'readmore_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Button Font', 'digital' ),
			'std'        => array(
				'preview-text'  => 'Read More Font',
				'preview-color' => 'light',
				'font-family'   => 'Raleway',
				'font-weight'   => '700',
				'font-size'     => '11px',
				'color'         => '#363a60',
				'css-selectors' => '.layout-' . $unique_id . ' .readMore a',
			),
			'dependency' => $readmore,
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'readmore_bg_color_' . $unique_id,
			'type'       => 'color',
			'title'      => esc_html__( 'Button Background Color', 'citation' ),
			'std'        => '#ffffff',
			'dependency' => $readmore,
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'readmore_border_' . $unique_id,
			'type'       => 'border',
			'title'      => esc_html__( 'Button Border', 'citation' ),
			'sub_desc'   => esc_html__( 'Select border.', 'citation' ),
			'std'        => array(
				'direction' => 'all',
				'size'      => '1',
				'style'     => 'solid',
				'color'     => '#363a60',
			),
			'dependency' => $readmore,
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'readmore_hover_color_' . $unique_id,
			'type'       => 'color',
			'title'      => esc_html__( 'Button Hover Color', 'citation' ),
			'std'        => citation_get_settings( 'primary_color_scheme' ),
			'dependency' => $readmore,
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'readmore_bg_hover_color_' . $unique_id,
			'type'       => 'color',
			'title'      => esc_html__( 'Bbutton Background Hover Color', 'citation' ),
			'std'        => '#ffffff',
			'dependency' => $readmore,
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'readmore_border_hover_color_' . $unique_id,
			'type'       => 'color',
			'title'      => esc_html__( 'Button Background Hover Color', 'citation' ),
			'std'        => citation_get_settings( 'primary_color_scheme' ),
			'dependency' => $readmore,
		) : null,
		// Post Container.
		( 'layout-2' === $posts_layout ) ? array(
			'id'    => 'post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'citation' ),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'citation' ),
			'sub_desc' => esc_html__( 'Select border', 'citation' ),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'citation' ),
			'sub_desc' => esc_html__( 'Post margin.', 'citation' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => citation_px_to_rem( '70px' ),
				'bottom' => '0',
			),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'citation' ),
			'sub_desc' => esc_html__( 'Post padding.', 'citation' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'    => 'post_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Title Font', 'citation' ),
			'std'   => array(
				'preview-text'  => 'Post Title Font',
				'preview-color' => 'light',
				'font-family'   => 'Raleway',
				'font-weight'   => '700',
				'font-size'     => '20px',
				'line-height'   => '1.2',
				'margin-bottom' => citation_px_to_rem( '10px' ),
				'color'         => '#363a60',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .title a',
			),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'    => 'post_excerpt_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Excerpt Font', 'citation' ),
			'std'   => array(
				'preview-text'  => 'Post Excerpt Font',
				'preview-color' => 'light',
				'font-family'   => 'Raleway',
				'font-weight'   => '400',
				'font-size'     => '14px',
				'margin-bottom' => citation_px_to_rem( '16px' ),
				'line-height'   => '1.5',
				'color'         => '#363a60',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .front-view-content',
			),
		) : null,

		/**
		 * Layout HTML Settings
		 *
		 * @package Citation
		 */
		( 'layout-html' === $posts_layout ) ? array(
			'id'       => 'post_layout_html_' . $unique_id,
			'type'     => 'ace_editor',
			'mode'     => 'html',
			'title'    => esc_html__( 'HTML Post', 'citation' ),
			'sub_desc' => esc_html__( 'Paste your HTML, Text or other code here.', 'citation' ),
			'std'      => '<img src="' . get_template_directory_uri() . '/images/banner-970.jpg">',
		) : null,
		( 'layout-html' === $posts_layout ) ? array(
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'citation' ),
			'sub_desc' => esc_html__( 'Post margin.', 'citation' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => '45px',
				'bottom' => '0',
			),
		) : null,
		( 'layout-html' === $posts_layout ) ? array(
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'citation' ),
			'sub_desc' => esc_html__( 'Post padding.', 'citation' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			),
		) : null,

	);
endforeach;
